@@ -16,6 +16,7 @@ from starlette.middleware import Middleware
 from starlette.middleware.base import BaseHTTPMiddleware
 from functools import partial
 import asyncio
+import os
 from hypercorn.config import Config
 from hypercorn.asyncio import serve
 from grpc import StatusCode
@@ -115,7 +116,8 @@ class GatewayServer(threading.Thread):
                 routes.append(route)
                 self.handlers[http_path] = {'service': service_handler._name, 'method': method_name}
     middleware = [Middleware(AccessLogMiddleware)]
-    app = Starlette(debug=True,
+    debug = 'DELPHAI_ENVIRONMENT' in os.environ and os.environ['DELPHAI_ENVIRONMENT'] == 'development'
+    app = Starlette(debug=debug,
                     routes=routes,
                     exception_handlers={HTTPException: self.http_exception},
                     middleware=middleware)
